@@ -5,7 +5,7 @@
 ;; Author: Protesilaos Stavrou <info@protesilaos.com>
 ;; Maintainer: Protesilaos Stavrou <info@protesilaos.com>
 ;; URL: https://github.com/protesilaos/pulsar
-;; Version: 1.3.0
+;; Version: 1.3.2
 ;; Package-Requires: ((emacs "28.1"))
 ;; Keywords: convenience, pulse, highlight
 
@@ -162,8 +162,7 @@ This only takes effect when `pulsar-mode' (buffer-local) or
     yank-rectangle)
   "Functions that highlight the affected region after invocation.
 When the value is nil, no pulsing is in effect.  Otherwise, the value is
-a list of functions that operate on the region.  It can be, for example,
-`pulsar-pulse-region-common-functions'.
+a list of functions that operate on the region.
 
 This only takes effect when `pulsar-mode' (buffer-local) or
 `pulsar-global-mode' is enabled."
@@ -388,7 +387,10 @@ extended to the edge of the window."
 (defun pulsar--create-pulse (locus face)
   "Create a pulse spanning the LOCUS using FACE.
 LOCUS is a cons cell with two buffer positions."
-  (let ((overlay (make-overlay (car locus) (cdr locus))))
+  (let ((pulse-flag t)
+        (pulse-delay pulsar-delay)
+        (pulse-iterations pulsar-iterations)
+        (overlay (make-overlay (car locus) (cdr locus))))
     (overlay-put overlay 'pulse-delete t)
     (overlay-put overlay 'window (frame-selected-window))
     (pulse-momentary-highlight-overlay overlay face)))
@@ -403,10 +405,7 @@ LOCUS is a cons cell with two buffer positions."
   "Create a pulse highlight for the current line.
 Also see `pulsar-highlight-pulse'."
   (interactive)
-  (let ((pulse-delay pulsar-delay)
-        (pulse-flag t)
-        (pulse-iterations pulsar-iterations))
-    (pulsar--create-pulse (pulsar--get-line-boundaries) pulsar-face)))
+  (pulsar--create-pulse (pulsar--get-line-boundaries) pulsar-face))
 
 ;;;###autoload
 (defun pulsar-highlight-pulse (&optional locus)
@@ -420,10 +419,7 @@ Otherwise, LOCUS spans the current line.
 For highlights without a pulse, see `pulsar-highlight-temporarily' and
 `pulsar-highlight-permanently'."
   (interactive (list (pulsar--get-line-or-region-boundaries)))
-  (let ((pulse-flag t)
-        (pulse-delay pulsar-delay)
-        (pulse-iterations pulsar-iterations))
-    (pulsar--create-pulse locus pulsar-face)))
+  (pulsar--create-pulse locus pulsar-face))
 
 (define-obsolete-function-alias
   'pulsar-highlight-line
@@ -446,8 +442,11 @@ For a permanent highlight, see `pulsar-highlight-permanently'."
   (interactive (list (pulsar--get-line-or-region-boundaries)))
   (let ((pulse-flag nil)
         (pulse-delay nil)
-        (pulse-iterations nil))
-    (pulsar--create-pulse locus pulsar-highlight-face)))
+        (pulse-iterations nil)
+        (overlay (make-overlay (car locus) (cdr locus))))
+    (overlay-put overlay 'pulse-delete t)
+    (overlay-put overlay 'window (frame-selected-window))
+    (pulse-momentary-highlight-overlay overlay pulsar-highlight-face)))
 
 ;;;###autoload
 (defun pulsar-highlight-permanently (locus)
